# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class MetroInput(BaseModel):
    """
    MetroInput
    """ # noqa: E501
    href: Optional[StrictStr] = None
    metro: StrictStr = Field(description="Metro code or ID of where the device should be provisioned in, or it can be instructed to create the device in the best available metro with `{ \"metro\": \"any\" }`. The special metro value of any means anywhere, any metro. When any is chosen in the request, the metro location is picked per our scheduling algorithms that favor the following factors: hardware reservation location (if requesting reserved hardware), ip reservations, spot instances, etc. The any keyword *does not* optimize for cost, this means that usage costs (instance, transfer, other features dependent on location) will vary. Please check metro value in response to see where the device was created. Either metro or facility must be provided.")
    __properties: ClassVar[List[str]] = ["href", "metro"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of MetroInput from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of MetroInput from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "href": obj.get("href"),
            "metro": obj.get("metro")
        })
        return _obj





# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.interconnection_port_list import InterconnectionPortList

class TestInterconnectionPortList(unittest.TestCase):
    """InterconnectionPortList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> InterconnectionPortList:
        """Test InterconnectionPortList
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `InterconnectionPortList`
        """
        model = InterconnectionPortList()
        if include_optional:
            return InterconnectionPortList(
                href = '',
                ports = [
                    equinix.services.metalv1.models.interconnection_port.InterconnectionPort(
                        href = '', 
                        id = '', 
                        link_status = '', 
                        name = '', 
                        organization = equinix.services.metalv1.models.href.Href(
                            href = '', ), 
                        role = 'primary', 
                        speed = 56, 
                        status = 'requested', 
                        switch_id = '', 
                        virtual_circuits = [
                            null
                            ], )
                    ]
            )
        else:
            return InterconnectionPortList(
        )
        """

    def testInterconnectionPortList(self):
        """Test InterconnectionPortList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.spot_market_prices_per_metro_report import SpotMarketPricesPerMetroReport

class TestSpotMarketPricesPerMetroReport(unittest.TestCase):
    """SpotMarketPricesPerMetroReport unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SpotMarketPricesPerMetroReport:
        """Test SpotMarketPricesPerMetroReport
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SpotMarketPricesPerMetroReport`
        """
        model = SpotMarketPricesPerMetroReport()
        if include_optional:
            return SpotMarketPricesPerMetroReport(
                am = equinix.services.metalv1.models.spot_prices_per_facility.SpotPricesPerFacility(
                    baremetal_0 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    baremetal_1 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    baremetal_2 = , 
                    baremetal_2a = , 
                    baremetal_2a2 = , 
                    baremetal_3 = , 
                    baremetal_s = , 
                    c2/medium/x86 = , 
                    href = '', 
                    m2/xlarge/x86 = , ),
                ch = equinix.services.metalv1.models.spot_prices_per_facility.SpotPricesPerFacility(
                    baremetal_0 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    baremetal_1 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    baremetal_2 = , 
                    baremetal_2a = , 
                    baremetal_2a2 = , 
                    baremetal_3 = , 
                    baremetal_s = , 
                    c2/medium/x86 = , 
                    href = '', 
                    m2/xlarge/x86 = , ),
                da = equinix.services.metalv1.models.spot_prices_per_facility.SpotPricesPerFacility(
                    baremetal_0 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    baremetal_1 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    baremetal_2 = , 
                    baremetal_2a = , 
                    baremetal_2a2 = , 
                    baremetal_3 = , 
                    baremetal_s = , 
                    c2/medium/x86 = , 
                    href = '', 
                    m2/xlarge/x86 = , ),
                href = '',
                la = equinix.services.metalv1.models.spot_prices_per_facility.SpotPricesPerFacility(
                    baremetal_0 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    baremetal_1 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    baremetal_2 = , 
                    baremetal_2a = , 
                    baremetal_2a2 = , 
                    baremetal_3 = , 
                    baremetal_s = , 
                    c2/medium/x86 = , 
                    href = '', 
                    m2/xlarge/x86 = , ),
                ny = equinix.services.metalv1.models.spot_prices_per_facility.SpotPricesPerFacility(
                    baremetal_0 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    baremetal_1 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    baremetal_2 = , 
                    baremetal_2a = , 
                    baremetal_2a2 = , 
                    baremetal_3 = , 
                    baremetal_s = , 
                    c2/medium/x86 = , 
                    href = '', 
                    m2/xlarge/x86 = , ),
                sg = equinix.services.metalv1.models.spot_prices_per_facility.SpotPricesPerFacility(
                    baremetal_0 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    baremetal_1 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    baremetal_2 = , 
                    baremetal_2a = , 
                    baremetal_2a2 = , 
                    baremetal_3 = , 
                    baremetal_s = , 
                    c2/medium/x86 = , 
                    href = '', 
                    m2/xlarge/x86 = , ),
                sv = equinix.services.metalv1.models.spot_prices_per_facility.SpotPricesPerFacility(
                    baremetal_0 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    baremetal_1 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                        href = '', 
                        price = 1.337, ), 
                    baremetal_2 = , 
                    baremetal_2a = , 
                    baremetal_2a2 = , 
                    baremetal_3 = , 
                    baremetal_s = , 
                    c2/medium/x86 = , 
                    href = '', 
                    m2/xlarge/x86 = , )
            )
        else:
            return SpotMarketPricesPerMetroReport(
        )
        """

    def testSpotMarketPricesPerMetroReport(self):
        """Test SpotMarketPricesPerMetroReport"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.vrf_virtual_circuit_update_input import VrfVirtualCircuitUpdateInput

class TestVrfVirtualCircuitUpdateInput(unittest.TestCase):
    """VrfVirtualCircuitUpdateInput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> VrfVirtualCircuitUpdateInput:
        """Test VrfVirtualCircuitUpdateInput
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `VrfVirtualCircuitUpdateInput`
        """
        model = VrfVirtualCircuitUpdateInput()
        if include_optional:
            return VrfVirtualCircuitUpdateInput(
                customer_ip = '12.0.0.2',
                customer_ipv6 = '2604:1380:4641:a00::6',
                description = '',
                href = '',
                md5 = 'jUR,rZ#UM/?R,Fp^l6$ARjeJk C>i H'qT\\{<?'es#)#iK.YM{Rag2/!KB!k@5oXh.:Ts\";mGL,i&z5[P@M\"lzfB+Y,Twzfu~N^z\"mfqecVU{SE{QA<Y8XX0<}J;Krm9W'g~?)DvDDL7BlwpCDcpNjORpuEG',
                metal_ip = '12.0.0.1',
                metal_ipv6 = '2604:1380:4641:a00::6',
                name = '',
                peer_asn = 65000,
                speed = '',
                subnet = '12.0.0.0/30',
                subnet_ipv6 = '2604:1380:4641:a00::4/126',
                tags = [
                    ''
                    ]
            )
        else:
            return VrfVirtualCircuitUpdateInput(
        )
        """

    def testVrfVirtualCircuitUpdateInput(self):
        """Test VrfVirtualCircuitUpdateInput"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.ip_reservation import IPReservation

class TestIPReservation(unittest.TestCase):
    """IPReservation unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> IPReservation:
        """Test IPReservation
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `IPReservation`
        """
        model = IPReservation()
        if include_optional:
            return IPReservation(
                addon = True,
                address = '',
                address_family = 56,
                assignments = [
                    equinix.services.metalv1.models.href.Href(
                        href = '', )
                    ],
                available = '',
                bill = True,
                cidr = 56,
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                customdata = None,
                details = '',
                enabled = True,
                facility = None,
                gateway = '',
                global_ip = True,
                href = '',
                id = '',
                manageable = True,
                management = True,
                metal_gateway = equinix.services.metalv1.models.metal_gateway_lite.MetalGatewayLite(
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    gateway_address = '10.1.2.1/27', 
                    href = '', 
                    id = '', 
                    state = 'ready', 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    vlan = 1001, ),
                metro = None,
                netmask = '',
                network = '',
                project = equinix.services.metalv1.models.project.Project(
                    backend_transfer_enabled = True, 
                    bgp_config = equinix.services.metalv1.models.href.Href(
                        href = '', ), 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    customdata = equinix.services.metalv1.models.customdata.customdata(), 
                    devices = [
                        equinix.services.metalv1.models.href.Href(
                            href = '', )
                        ], 
                    href = '', 
                    id = '', 
                    invitations = [
                        
                        ], 
                    max_devices = equinix.services.metalv1.models.max_devices.max_devices(), 
                    members = [
                        
                        ], 
                    memberships = [
                        
                        ], 
                    name = '0', 
                    network_status = equinix.services.metalv1.models.network_status.network_status(), 
                    organization = , 
                    payment_method = , 
                    ssh_keys = [
                        
                        ], 
                    tags = [
                        ''
                        ], 
                    type = 'default', 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    url = '', 
                    volumes = [
                        
                        ], ),
                project_lite = equinix.services.metalv1.models.href.Href(
                    href = '', ),
                public = True,
                requested_by = equinix.services.metalv1.models.href.Href(
                    href = '', ),
                state = '',
                tags = [
                    ''
                    ],
                type = 'global_ipv4'
            )
        else:
            return IPReservation(
                type = 'global_ipv4',
        )
        """

    def testIPReservation(self):
        """Test IPReservation"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.operating_system import OperatingSystem

class TestOperatingSystem(unittest.TestCase):
    """OperatingSystem unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> OperatingSystem:
        """Test OperatingSystem
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OperatingSystem`
        """
        model = OperatingSystem()
        if include_optional:
            return OperatingSystem(
                build_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(),
                default_operating_system = True,
                deprecation_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(),
                distro = '',
                distro_label = '',
                end_of_life_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(),
                end_of_service_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(),
                href = '',
                id = '',
                licensed = True,
                lifecycle_state = '',
                name = '',
                preinstallable = True,
                pricing = equinix.services.metalv1.models.pricing.pricing(),
                provisionable_on = [
                    ''
                    ],
                release_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(),
                release_notes = '',
                slug = '',
                version = ''
            )
        else:
            return OperatingSystem(
        )
        """

    def testOperatingSystem(self):
        """Test OperatingSystem"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from equinix.services.metalv1.models.address import Address
from typing import Optional, Set
from typing_extensions import Self

class OrganizationInput(BaseModel):
    """
    OrganizationInput
    """ # noqa: E501
    address: Optional[Address] = None
    billing_address: Optional[Address] = None
    customdata: Optional[Dict[str, Any]] = None
    description: Optional[StrictStr] = None
    enforce_2fa_at: Optional[datetime] = Field(default=None, description="Force to all members to have enabled the two factor authentication after that date, unless the value is null")
    href: Optional[StrictStr] = None
    name: Optional[StrictStr] = None
    twitter: Optional[StrictStr] = None
    website: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["address", "billing_address", "customdata", "description", "enforce_2fa_at", "href", "name", "twitter", "website"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of OrganizationInput from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of address
        if self.address:
            _dict['address'] = self.address.to_dict()
        # override the default output from pydantic by calling `to_dict()` of billing_address
        if self.billing_address:
            _dict['billing_address'] = self.billing_address.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of OrganizationInput from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "address": Address.from_dict(obj["address"]) if obj.get("address") is not None else None,
            "billing_address": Address.from_dict(obj["billing_address"]) if obj.get("billing_address") is not None else None,
            "customdata": obj.get("customdata"),
            "description": obj.get("description"),
            "enforce_2fa_at": obj.get("enforce_2fa_at"),
            "href": obj.get("href"),
            "name": obj.get("name"),
            "twitter": obj.get("twitter"),
            "website": obj.get("website")
        })
        return _obj


